@@ -31,14 +31,17 @@ def main(target, ground, output, variables=None, mappings=None, authtype="pba"):
         target = make_lower(load_json(target))
         ground = make_lower(load_json(ground))
         v = None
+        print(variables)
 
         if variables:
-            v = read_csv(variables)
+            if str(variables).endswith(".csv"):
+                v = read_csv(variables)
+            else:
+                v = load_json(variables)
 
         version_map = {}
         path = f"src/scribe_updater/version_mapping/{mappings}"
         if os.path.isfile(path):
-            click.echo(f"mapping found : {path}")
             version_map = load_json(path)
         else:
             click.echo(f"mapping not found : {path}")
