@@ -4,17 +4,24 @@ import os
 from scribe_updater.changelog import ChangeLog
 from scribe_updater.utils import (
     get_competencies,
-    get_product_names,
     get_glia_vba,
+    get_product_names,
     get_scenarios,
     process_competency,
-    process_variable_rows,
+    process_variable_rows_csv,
+    process_variable_rows_json,
 )
 
 
 class Updater:
     def __init__(
-        self, ground, target, variables, output_file_path, ground_to_target_map
+        self,
+        ground,
+        target,
+        variables,
+        output_file_path,
+        ground_to_target_map,
+        is_csv=False,
     ):
         self.ground = ground
         self.target = target
@@ -27,6 +34,7 @@ class Updater:
         self.output = {}
         self.output_file_path = output_file_path
         self.ground_to_target_map = ground_to_target_map
+        self.is_csv = is_csv
 
     def set_ground_scenarios(self):
         """
@@ -60,7 +68,11 @@ class Updater:
             self.is_glia_vba = False
             return
 
-        v = process_variable_rows(self.variables)
+        v = (
+            process_variable_rows_json(self.variables)
+            if not self.is_csv
+            else process_variable_rows_csv(self.variables)
+        )
         products = get_product_names(v)
         self.products = products
         self.is_glia_vba = get_glia_vba(v)
