@@ -297,7 +297,7 @@ def make_lower(data: dict):
     return data
 
 
-def process_variable_rows(variables):
+def process_variable_rows_csv(variables):
     """
     Processes the rows of the CSV for the Variables sheet into a list of variables
     """
@@ -319,6 +319,26 @@ def process_variable_rows(variables):
     return {"variables": v}
 
 
+def process_variable_rows_json(variables):
+    """
+    Processes the variables.json file, it is similar the the process_variable_rows_csv function
+    """
+    v = []
+
+    for row in variables.get("variables"):
+        value: str = row["value"]
+        if value.lower() in ["true", "false"]:
+            value = value.lower()
+
+        v.append(
+            {
+                "name": row["name"],
+                "value": value,
+            }
+        )
+    return {"variables": v}
+
+
 def get_variable(variables: dict, variable_name):
     v = variables.get("variables", [])
     for variable in v:
